| Title: | Market Odds Data from Pinnacle |
|---|---|
| Description: | Market odds from from Pinnacle, an online sports betting bookmaker (see <https://www.pinnacle.com> for more information). Included are datasets for the Major League Baseball (MLB) 2016 season and the USA election 2016. These datasets can be used to build models and compare statistical information with the information from prediction markets.The Major League Baseball (MLB) 2016 dataset can be used for sabermetrics analysis and also can be used in conjunction with other popular Major League Baseball (MLB) datasets such as Retrosheets or the Lahman package by merging by GameID. |
| Authors: | Marco Blume, Michael Yan |
| Maintainer: | Marco Blume <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.5 |
| Built: | 2026-05-18 07:15:23 UTC |
| Source: | https://github.com/marcoblume/pinnacle.data |
Major League Baseball (MLB) data for the 2016 season.
MLB2016MLB2016
A tibble with 20 variables:
GameIDsame format as Retrosheets and BaseballReference data
EventDateTimeUTCTime of the game in UTC
EventDateTimeETTime of the game in Eastern Standardtime
AwayTeamTeam name of the Away Team
HomeTeamTeam name of the Home Team
DoubleHeaderGameIndicates if this was a double Header
AwayStartingPitcherStarting pitcher Away Team
HomeStartingPitcherStarting pitcher Home Team
FinalScoreAwayRuns scored by Away Team
FinalScoreHomeRuns scored by Home Team
EnteredDateTimeUTCTime of the wager line in UTC
EnteredDateTimeETTime of the wager line in Eastern Standardtime
SpreadTeam1Spread Handicap for Away Team
SpreadUS1Spread US odds for Away Team
SpreadUS2Spread US odds for Home Team
MoneyUS1Moneyline US odds for Away Team
MoneyUS2Moneyline US odds for Home Team
TotalPointsTotal runs handicap
TotalUSOverTotal runs US odds for Over
TotalUSUnderTotal runs US odds for Under
All wagering lines from Pinnacle for the 2016 MLB season
if (require("tidyverse")) { library(tidyverse) # What was the range of expected total runs according to the prediction market at Pinnacle? MLB2016 %>% unnest() %>% group_by(GameID) %>% arrange(desc(EnteredDateTimeUTC)) %>% slice(1) %>% ungroup() %>% group_by(TotalPoints) %>% summarize(Count = n()) # How many games went Over/Under/Landed on the total? MLB2016 %>% unnest() %>% group_by(GameID) %>% arrange(desc(EnteredDateTimeUTC)) %>% slice(1) %>% ungroup() %>% select(GameID,TotalPoints,FinalScoreAway,FinalScoreHome) %>% mutate(TotalOutcome = case_when( FinalScoreAway + FinalScoreHome > TotalPoints ~ "Over", FinalScoreAway + FinalScoreHome < TotalPoints ~ "Under", FinalScoreAway + FinalScoreHome == TotalPoints ~ "Landed" ) ) %>% group_by(TotalPoints,TotalOutcome) %>% summarize(Count = n()) %>% print(n=100) }if (require("tidyverse")) { library(tidyverse) # What was the range of expected total runs according to the prediction market at Pinnacle? MLB2016 %>% unnest() %>% group_by(GameID) %>% arrange(desc(EnteredDateTimeUTC)) %>% slice(1) %>% ungroup() %>% group_by(TotalPoints) %>% summarize(Count = n()) # How many games went Over/Under/Landed on the total? MLB2016 %>% unnest() %>% group_by(GameID) %>% arrange(desc(EnteredDateTimeUTC)) %>% slice(1) %>% ungroup() %>% select(GameID,TotalPoints,FinalScoreAway,FinalScoreHome) %>% mutate(TotalOutcome = case_when( FinalScoreAway + FinalScoreHome > TotalPoints ~ "Over", FinalScoreAway + FinalScoreHome < TotalPoints ~ "Under", FinalScoreAway + FinalScoreHome == TotalPoints ~ "Landed" ) ) %>% group_by(TotalPoints,TotalOutcome) %>% summarize(Count = n()) %>% print(n=100) }
US Presidential Election data 2016.
USA_Election_2016USA_Election_2016
A data.frame with 5 variables:
EnteredDateTimeTime of the wager line in UTC
TeamName1Team name of the Away Team
TeamName2Team name of the Home Team
MoneyUS1Moneyline US odds for Away Team
MoneyUS2Moneyline US odds for Home Team
All lines from Pinnacle for the 2016 US Presidential Election
if (require("odds.converter")) { library(tidyverse) # What is Hilary Clinton's the highest implied winning probability at Pinnacle? USA_Election_2016[which.min(USA_Election_2016$MoneyUS1),"EnteredDateTime"] odds.converter::odds.us2prob(min(USA_Election_2016$MoneyUS1)) } # What time on election night that Trump's implied winning probability surpassed Clinton's? if (require("tidyverse")) { library(tidyverse) USA_Election_2016 %>% filter(MoneyUS1>MoneyUS2) %>% slice(1) }if (require("odds.converter")) { library(tidyverse) # What is Hilary Clinton's the highest implied winning probability at Pinnacle? USA_Election_2016[which.min(USA_Election_2016$MoneyUS1),"EnteredDateTime"] odds.converter::odds.us2prob(min(USA_Election_2016$MoneyUS1)) } # What time on election night that Trump's implied winning probability surpassed Clinton's? if (require("tidyverse")) { library(tidyverse) USA_Election_2016 %>% filter(MoneyUS1>MoneyUS2) %>% slice(1) }